==> nextcloud-app-notes-4.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/fa.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "یادداشت ها",
    "Reading notes from filesystem has failed." : "خواندن یادداشت ها از پوشه ی سیستم با شکست مواجه شده است",
    "Error" : "خطا",
    "New note" : "یادداشت جدید",
    "Distraction-free notes and writing" : "یادداشت ها و نوشتن بدون حواس پرتی",
    "Please see Nextcloud server log for details." : "لطفا لاگ سرور nextcloud را برای جزییات بیشتر مشاهده نمایید .",
    "Deleted {title}" : "حذف شده {عنوان}",
    "Note recovered" : "یادداشت بازیابی شده",
    "There are unsaved notes. Leaving the page will discard all changes!" : "یادداشتهای ذخیره نشده وجود دارد. ترک صفحه باعث می شود همه تغییرات از بین بروند!",
    "Settings" : "تنظیمات",
    "Folder to store your notes" : "پوشه برای ذخیره یادداشت های خود",
    "File extension for new notes" : "پسوند پرونده برای یادداشتهای جدید",
    "Display mode for notes" : "حالت نمایش یادداشت‌ها",
    "Open in edit mode" : " یادداشت را در حالت «ویرایش» باز کنید",
    "Open in preview mode" : "یادداشت را در حالت پیش نمایش باز کنید",
    "No notes yet" : "هنوز هیچ یادداشتی وجود ندارد",
    "All notes" : "همه یادداشت ها",
    "Categories" : "دسته بندی ها",
    "Loading …" : "بارگذاری …",
    "Today" : "Today",
    "Yesterday" : "دیروز",
    "This week" : "این هفته",
    "Last week" : "هفته گذشته",
    "This month" : "این ماه",
    "Last month" : "ماه گذشته",
    "Rename" : "تغییرنام",
    "Note's title" : "موضوع یادداشت ها",
    "Delete note" : "حذف یادداشت",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "افزودن به علاقه مندی ها",
    "Error during preparing note for deletion." : "در هنگام آماده سازی یادداشت برای حذف خطایی رخ داده است",
    "Use current version" : "از نسخه فعلی استفاده کنید",
    "Empty note" : "یادداشت خالی",
    "Write …" : "نوشتن …",
    "Details" : "جزئیات",
    "Edit" : "ویرایش",
    "Preview" : "پیش نمایش",
    "Exit full screen" : "خروج از تمام صفحه",
    "Full screen" : "تمام صفحه",
    "Save failed. Click to retry." : "ذخیره نشد. برای امتحان دوباره کلیک کنید",
    "Error from Nextcloud server: {msg}" : "خطا از سرور نکست کلود : {msg}",
    "Set category" : "تنظیم مجموعه",
    "Category" : "دسته‌بندی",
    "Uncategorized" : "دستهبندی نشده",
    "Click here to save manually" : "برای ذخیره دستی اینجا را کلیک کنید",
    "Saving failed!" : "پس انداز نشد!",
    "Last modified: {date}" : "آخرین اصلاح: {تاریخ}",
    "Note has unsaved changes" : "توجه داشته باشید تغییرات ذخیره نشده دارد",
    "Subcategory" : "زیر مجموعه",
    "_%n word_::_%n words_" : ["%n کلمه","%n کلمه"],
    "Write down your thoughts without any distractions." : "افکار خود را بدون هیچ گونه حواس پرتی بنویسید.",
    "Use Markdown markups to style your text." : "برای نشان دادن متن خود از نشانگرهای Markdown استفاده کنید.",
    "Organize your notes in categories." : "یادداشت های خود را در دسته بندی ها ترتیب دهید.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "برای دسترسی به یادداشت های خود از همه جا ، برنامه تلفن همراه خود را نصب کنید.",
    "Android app" : "اپ اندروید",
    "iOS app" : "اپ iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "نوشتن یادداشت را با کلیک کردن روی \"{newnote}\" در ناوبری برنامه شروع کنید.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "شما می توانید زیر شاخه ها با استفاده از به عنوان حائل بین دسته پدر و مادر و زیرشاخه، به عنوان مثال، ایجاد \"/\" \"{پدر و مادر} / {زیر}\".",
    "Note not found." : "یادداشتی یافت نشد",
    "Note is locked." : "یادداشت قفل شده است",
    "Updating settings has failed." : "به روزرسانی تنظیمات انجام نشد.",
    "Fetching notes has failed." : "ثبت نام یادداشت انجام نشد.",
    "Fetching note {id} has failed." : "یادداشت برداری {id} انجام نشد.",
    "Creating new note has failed." : "ایجاد یادداشت جدید انجام نشد.",
    "Deleting note {id} has failed." : "حذف یادداشت {شناسه} انجام نشد.",
    "Toggling favorite for note {id} has failed." : "روشن نیست مورد علاقه برای توجه داشته باشید {id} تعریف شکست خورده است.",
    "Updating the note's category has failed. Is the target directory writable?" : "به روزرسانی دسته یادداشت انجام نشد. آیا فهرست مسیر قابل نوشتن است؟",
    "Updating the category for note {id} has failed." : "به روزرسانی دسته برای یادداشت {id} انجام نشد.",
    "Development Mode" : "حالت توسعه",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "به نظر می رسد که برنامه یادداشت ها از یک منبع توسعه نصب شده است. لطفاً آن را از طریق رسمی  نصب کنید <a href=\"%1$s\">فروشگاه برنامه نکست کلود</a>بجای.اگر می خواهید برنامه Notes توسط خودتان بسازید ، لطفاً دنبال کنید <a href=\"%2$s\">دستورالعمل های توسعه دهنده</a>."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-notes-4.8.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/fa.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "یادداشت ها",
    "Create new note" : "ایجاد یادداشت جدید",
    "More notes" : "یادداشت‌های بیشتر",
    "Reading notes from filesystem has failed." : "خواندن یادداشت ها از پوشه ی سیستم با شکست مواجه شده است",
    "Error" : "خطا",
    "New note" : "یادداشت جدید",
    "Distraction-free notes and writing" : "یادداشت ها و نوشتن بدون حواس پرتی",
    "Notes settings" : "تنظیمات یادداشت‌ها",
    "Please see Nextcloud server log for details." : "لطفا لاگ سرور nextcloud را برای جزییات بیشتر مشاهده نمایید .",
    "Deleted {title}" : "{title} حذف شد",
    "Note recovered" : "یادداشت بازیابی شده",
    "There are unsaved notes. Leaving the page will discard all changes!" : "یادداشتهای ذخیره نشده وجود دارد. ترک صفحه باعث می شود همه تغییرات از بین بروند!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} یادداشت حذف شد","{number} یادداشت حذف شدند"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} یادداشت یازیابی شد","{number} یادداشت یازیابی شدند"],
    "Basics" : "مقدمات",
    "Write down your thoughts without any distractions." : "افکار خود را بدون هیچ گونه حواس پرتی بنویسید.",
    "Organize your notes in categories." : "یادداشت های خود را در دسته بندی ها ترتیب دهید.",
    "Notes path" : "نشانی یادداشت‌ها",
    "Folder to store your notes" : "پوشه برای ذخیره یادداشت های خود",
    "Root directory" : "پوشه ریشه",
    "File extension" : "پسوند پرونده",
    "File extension for new notes" : "پسوند پرونده برای یادداشتهای جدید",
    "Display mode" : "حالت نمایش",
    "Display mode for notes" : "حالت نمایش یادداشت‌ها",
    "Shortcuts" : "میان‌برها",
    "Use shortcuts to quickly navigate this app." : "از میان‌برها برای جابجایی سریع در برنامه استفاده کنید",
    "Shortcut" : "میان‌بر",
    "Action" : "عمل",
    "Mobile apps" : "کاره‌های همراه",
    "User defined" : "تعریف‌شده توسط کاربر",
    "Open in rich text mode" : "بازکردن در حالت متن غنی",
    "Open in edit mode" : " یادداشت را در حالت «ویرایش» باز کنید",
    "Open in preview mode" : "یادداشت را در حالت پیش نمایش باز کنید",
    "Make the selection bold" : "متن انتخابی ضخیم شود",
    "Make the selection italic" : "متن انتخابی کج شود",
    "Wrap the selection in quotes" : "قراردادن متن انتخابی در علامت نقل‌قول",
    "The selection will be turned into monospace" : "متن انتخابی به monospace تغییر خواهد بافت",
    "All notes" : "همه یادداشت ها",
    "Categories" : "دسته بندی ها",
    "Create a sample note with Markdown" : "ایجاد یادداشت نمونه با مارک‌داون",
    "No notes yet" : "هنوز هیچ یادداشتی وجود ندارد",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "برای دسترسی به یادداشت های خود از همه جا ، برنامه تلفن همراه خود را نصب کنید.",
    "Keep plain Markdown editor" : "حفظ ویرایش‌گر ساده مارک‌داون",
    "Details" : "جزئیات",
    "Delete note" : "حذف یادداشت",
    "Remove from favorites" : "حذف از برگزیده‌ها",
    "Add to favorites" : "افزودن به علاقه مندی ها",
    "Error during preparing note for deletion." : "در هنگام آماده سازی یادداشت برای حذف خطایی رخ داده است",
    "Use current version" : "از نسخه فعلی استفاده کنید",
    "Empty note" : "یادداشت خالی",
    "Write …" : "نوشتن …",
    "Edit" : "ویرایش",
    "Preview" : "پیش نمایش",
    "Exit full screen" : "خروج از تمام صفحه",
    "Full screen" : "تمام صفحه",
    "Save failed. Click to retry." : "ذخیره نشد. برای امتحان دوباره کلیک کنید",
    "Error from Nextcloud server: {msg}" : "خطا از سرور نکست کلود : {msg}",
    "Loading …" : "بارگذاری …",
    "Today" : "Today",
    "Yesterday" : "دیروز",
    "This week" : "این هفته",
    "Last week" : "هفته گذشته",
    "This month" : "این ماه",
    "Last month" : "ماه گذشته",
    "Category" : "دسته‌بندی",
    "Uncategorized" : "دسته‌بندی نشده",
    "Set category" : "تنظیم مجموعه",
    "Click here to save manually" : "برای ذخیره دستی اینجا را کلیک کنید",
    "Saving failed!" : "پس انداز نشد!",
    "Last modified: {date}" : "آخرین تغییرات: {date}",
    "Note has unsaved changes" : "توجه داشته باشید تغییرات ذخیره نشده دارد",
    "Subcategory" : "زیر مجموعه",
    "_%n word_::_%n words_" : ["%n کلمه","%n کلمه"],
    "Use Markdown markups to style your text." : "برای سبک‌دهی به متن خود از نشانگرهای مارک‌داون استفاده کنید.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "نوشتن یادداشت را با کلیک کردن روی \"{newnote}\" در ناوبری برنامه شروع کنید.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "شما می توانید با کمک «/» به عنوان حائل میان دسته والد و زیردسته، اقدام به ایجاد زیردسته کنید، مثل «{parent}/{sub}»",
    "Note not found." : "یادداشتی یافت نشد",
    "Note is locked." : "یادداشت قفل شده است",
    "Updating settings has failed." : "به روزرسانی تنظیمات انجام نشد.",
    "Fetching notes has failed." : "ثبت نام یادداشت انجام نشد.",
    "Fetching note {id} has failed." : "یادداشت برداری {id} انجام نشد.",
    "Creating new note has failed." : "ایجاد یادداشت جدید انجام نشد.",
    "Deleting note {id} has failed." : "حذف یادداشت {id} شکست خورد.",
    "Toggling favorite for note {id} has failed." : "تغییر وضعیت علاقه‌مندی برای یادداشت {id} شکست خورد.",
    "Updating the note's category has failed. Is the target directory writable?" : "به روزرسانی دسته یادداشت انجام نشد. آیا فهرست مسیر قابل نوشتن است؟",
    "Updating the category for note {id} has failed." : "به‌روزرسانی دسته برای یادداشت {id} شکست خورد.",
    "Tasks" : "وظایف",
    "Nextcloud, a safe home for all your data" : "نکست‌کلود، خانه‌ای امن برای تمامی داده‌هایتان",
    "Development Mode" : "حالت توسعه",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "به نظر می رسد که برنامه یادداشت ها از یک منبع توسعه نصب شده است. لطفاً آن را از طریق رسمی  نصب کنید <a href=\"%1$s\">فروشگاه برنامه نکست کلود</a>بجای.اگر می خواهید برنامه Notes توسط خودتان بسازید ، لطفاً دنبال کنید <a href=\"%2$s\">دستورالعمل های توسعه دهنده</a>."
},
"nplurals=2; plural=(n > 1);");
